@@ -20,12 +20,12 @@
 #include <gtk/gtk.h>
 #include <libaudcore/i18n.h>
 #include <libaudgui/libaudgui.h>
+#include <libaudgui/libaudgui-gtk.h>
 
 #include "callbacks.h"
 
-const char *help[] =
-{
-   N_("Time\n"
+static const char help_text[] =
+ N_("Time\n"
     "  Alarm at:\n"
     "    The time for the alarm to come on.\n\n"
 
@@ -40,9 +40,9 @@ const char *help[] =
     "  Time:\n"
     "    Choose the time for the alarm on each day,\n"
     "    or select the toggle button to use the default\n"
-    "    time.\n\n\n"),
+    "    time.\n\n\n"
 
-   N_("Volume\n"
+    "Volume\n"
     "  Fading:\n"
     "    Fade the volume up to the chosen volume\n"
     "    for this amount of time.\n\n"
@@ -57,9 +57,9 @@ const char *help[] =
 
     "Options:\n"
     "  Additional Command:\n"
-    "    Run this command at the alarm time.\n\n"),
+    "    Run this command at the alarm time.\n\n"
 
-   N_("  Playlist:\n"
+    "  Playlist:\n"
     "    Load this playlist. If no playlist\n"
     "    is given, the current one will be used.\n"
     "    The URL of an mp3/ogg stream\n"
@@ -67,13 +67,10 @@ const char *help[] =
 
     "  Reminder:\n"
     "    Display a reminder when the alarm goes off.\n"
-    "    Type the reminder in the box and turn on the\n"
-    "    toggle button if you want it to be shown."),
+    "    Type the reminder in the input field and enable\n"
+    "    the checkbox if you want it to be shown.");
 
-    nullptr
-};
-
-GtkWidget *create_alarm_dialog (void)
+GtkWidget *create_alarm_dialog ()
 {
     GtkWidget *alarm_dialog;
 
@@ -106,14 +103,7 @@ GtkWidget *create_reminder_dialog (const char *reminder_msg)
     return reminder_dialog;
 }
 
-static void file_set_cb (GtkFileChooserButton *button, void * entry)
-{
-    char *uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (button));
-    gtk_entry_set_text (GTK_ENTRY (entry), uri);
-    g_free (uri);
-}
-
-GtkWidget *create_config_notebook (void)
+GtkWidget *create_config_notebook ()
 {
     /* General */
     GtkWidget *notebook;
@@ -129,8 +119,8 @@ GtkWidget *create_config_notebook (void)
     GtkWidget *checkbutton;
     GtkWidget *widget[21];
 
-    const char *weekdays[] = { _("Monday"), _("Tuesday"), _("Wednesday"),
-                                _("Thursday"), _("Friday"), _("Saturday"), _("Sunday") };
+    const char *weekdays[] = { N_("Monday"), N_("Tuesday"), N_("Wednesday"),
+                               N_("Thursday"), N_("Friday"), N_("Saturday"), N_("Sunday") };
 
     const char *day_cb[] = { "mon_cb", "tue_cb", "wed_cb", "thu_cb",
                               "fri_cb", "sat_cb", "sun_cb" };
@@ -154,13 +144,12 @@ GtkWidget *create_config_notebook (void)
     GtkWidget *fading_spin, *quiet_vol_scale, *vol_scale, *separator, *current_button;
 
     /* Page 4 */
-    GtkWidget  *cmd_entry, *playlist_entry, *reminder_text;
-    GtkWidget *cmd_checkb, *reminder_checkb, *file_chooser_button;
+    GtkWidget *cmd_entry, *playlist_entry, *reminder_text;
+    GtkWidget *cmd_checkb, *reminder_checkb;
 
     /* Page 5 */
     GtkWidget *view, *scrolled_window;
     GtkTextBuffer *text_buffer;
-    char *help_text;
 
 
     /* General */
@@ -170,7 +159,7 @@ GtkWidget *create_config_notebook (void)
     /* Page 1 */
     frame = gtk_frame_new (_("Time"));
     gtk_container_set_border_width (GTK_CONTAINER (frame), 6);
-    grid = gtk_table_new (0, 0, FALSE);
+    grid = gtk_table_new (0, 0, false);
     gtk_table_set_col_spacings (GTK_TABLE (grid), 6);
     gtk_table_set_row_spacings (GTK_TABLE (grid), 6);
     gtk_container_set_border_width (GTK_CONTAINER (grid), 6);
@@ -182,8 +171,8 @@ GtkWidget *create_config_notebook (void)
     alarm_h_spin = gtk_spin_button_new (adjustment, 1, 0);
     g_object_set_data (G_OBJECT (notebook), "alarm_h_spin", alarm_h_spin);
     gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (alarm_h_spin), GTK_UPDATE_IF_VALID);
-    gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (alarm_h_spin), TRUE);
-    gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (alarm_h_spin), TRUE);
+    gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (alarm_h_spin), true);
+    gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (alarm_h_spin), true);
     gtk_table_attach (GTK_TABLE (grid), alarm_h_spin, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 
     label = gtk_label_new (":");
@@ -193,8 +182,8 @@ GtkWidget *create_config_notebook (void)
     alarm_m_spin = gtk_spin_button_new (adjustment, 1, 0);
     g_object_set_data (G_OBJECT (notebook), "alarm_m_spin", alarm_m_spin);
     gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (alarm_m_spin), GTK_UPDATE_IF_VALID);
-    gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (alarm_m_spin), TRUE);
-    gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (alarm_m_spin), TRUE);
+    gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (alarm_m_spin), true);
+    gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (alarm_m_spin), true);
     gtk_table_attach (GTK_TABLE (grid), alarm_m_spin, 3, 4, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 
     label = gtk_label_new (_("h"));
@@ -208,8 +197,8 @@ GtkWidget *create_config_notebook (void)
     stop_h_spin = gtk_spin_button_new (adjustment, 1, 0);
     g_object_set_data (G_OBJECT (notebook), "stop_h_spin", stop_h_spin);
     gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (stop_h_spin), GTK_UPDATE_IF_VALID);
-    gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (stop_h_spin), TRUE);
-    gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (stop_h_spin), TRUE);
+    gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (stop_h_spin), true);
+    gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (stop_h_spin), true);
     gtk_table_attach (GTK_TABLE (grid), stop_h_spin, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 
     label = gtk_label_new (_("hours"));
@@ -219,8 +208,8 @@ GtkWidget *create_config_notebook (void)
     stop_m_spin = gtk_spin_button_new (adjustment, 1, 0);
     g_object_set_data (G_OBJECT (notebook), "stop_m_spin", stop_m_spin);
     gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (stop_m_spin), GTK_UPDATE_IF_VALID);
-    gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (stop_m_spin), TRUE);
-    gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (stop_m_spin), TRUE);
+    gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (stop_m_spin), true);
+    gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (stop_m_spin), true);
     gtk_table_attach (GTK_TABLE (grid), stop_m_spin, 3, 4, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 
     label = gtk_label_new (_("minutes"));
@@ -234,7 +223,7 @@ GtkWidget *create_config_notebook (void)
     /* Page 2 */
     frame = gtk_frame_new (_("Choose the days for the alarm to come on"));
     gtk_container_set_border_width (GTK_CONTAINER (frame), 6);
-    grid = gtk_table_new (0, 0, FALSE);
+    grid = gtk_table_new (0, 0, false);
     gtk_table_set_col_spacings (GTK_TABLE (grid), 6);
     gtk_table_set_row_spacings (GTK_TABLE (grid), 6);
     gtk_container_set_border_width (GTK_CONTAINER (grid), 6);
@@ -247,18 +236,18 @@ GtkWidget *create_config_notebook (void)
 
     for (i = 0; i < 7; i ++)
     {
-        widget[i] = gtk_check_button_new_with_label (weekdays[i]);
+        widget[i] = gtk_check_button_new_with_label (_(weekdays[i]));
         g_object_set_data (G_OBJECT (notebook), day_cb[i], widget[i]);
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget[i]), TRUE);
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget[i]), true);
         gtk_table_attach (GTK_TABLE (grid), widget[i], 0, 1, i + 1, i + 2, GTK_FILL, GTK_FILL, 0, 0);
     }
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget[6]), FALSE);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget[6]), false);
 
     for (i = 0; i < 7; i ++)
     {
         checkbutton = gtk_check_button_new_with_label (_("Default"));
         g_object_set_data (G_OBJECT (notebook), day_def[i], checkbutton);
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), TRUE);
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
         g_signal_connect (checkbutton, "toggled", G_CALLBACK (cb_def[i]), nullptr);
         gtk_table_attach (GTK_TABLE (grid), checkbutton, 1, 2, i + 1, i + 2, GTK_FILL, GTK_FILL, 0, 0);
     }
@@ -291,8 +280,8 @@ GtkWidget *create_config_notebook (void)
 
 
     /* Page 3 */
-    vbox = gtk_vbox_new (FALSE, 6);
-    hbox = gtk_hbox_new (FALSE, 6);
+    vbox = gtk_vbox_new (false, 6);
+    hbox = gtk_hbox_new (false, 6);
 
     frame = gtk_frame_new (_("Fading"));
     gtk_container_set_border_width (GTK_CONTAINER (frame), 6);
@@ -300,101 +289,98 @@ GtkWidget *create_config_notebook (void)
     adjustment = (GtkAdjustment *) gtk_adjustment_new (120, 0, 3600, 1, 10, 0);
     fading_spin = gtk_spin_button_new (adjustment, 1, 0);
     g_object_set_data (G_OBJECT (notebook), "fading_spin", fading_spin);
-    gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (fading_spin), TRUE);
+    gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (fading_spin), true);
     gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (fading_spin), GTK_UPDATE_IF_VALID);
     label = gtk_label_new (_("seconds"));
 
-    gtk_box_pack_start (GTK_BOX (hbox), fading_spin, TRUE, TRUE, 0);
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), fading_spin, true, true, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), label, false, false, 0);
     gtk_container_add (GTK_CONTAINER (frame), hbox);
-    gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), frame, false, false, 0);
 
     frame = gtk_frame_new (_("Volume"));
-    vbox2 = gtk_vbox_new (FALSE, 6);
+    vbox2 = gtk_vbox_new (false, 6);
     gtk_container_set_border_width (GTK_CONTAINER (frame), 6);
     gtk_container_set_border_width (GTK_CONTAINER (vbox2), 6);
 
     label = gtk_label_new (_("Start at"));
-    gtk_box_pack_start (GTK_BOX (vbox2), label, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox2), label, false, false, 0);
 
     quiet_vol_scale = gtk_hscale_new ((GtkAdjustment *) gtk_adjustment_new (20, 0, 100, 1, 5, 0));
     g_object_set_data (G_OBJECT (notebook), "quiet_vol_scale", quiet_vol_scale);
     gtk_scale_set_value_pos (GTK_SCALE (quiet_vol_scale), GTK_POS_RIGHT);
     gtk_scale_set_digits (GTK_SCALE (quiet_vol_scale), 0);
     label = gtk_label_new ("%");
-    hbox2 = gtk_hbox_new (FALSE, 6);
-    gtk_box_pack_start (GTK_BOX (hbox2), quiet_vol_scale, TRUE, TRUE, 0);
-    gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
+    hbox2 = gtk_hbox_new (false, 6);
+    gtk_box_pack_start (GTK_BOX (hbox2), quiet_vol_scale, true, true, 0);
+    gtk_box_pack_start (GTK_BOX (hbox2), label, false, false, 0);
+    gtk_box_pack_start (GTK_BOX (vbox2), hbox2, false, false, 0);
 
     separator = gtk_hseparator_new ();
-    gtk_box_pack_start (GTK_BOX (vbox2), separator, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox2), separator, false, false, 0);
 
     label = gtk_label_new (_("Final"));
-    gtk_box_pack_start (GTK_BOX (vbox2), label, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox2), label, false, false, 0);
 
     vol_scale = gtk_hscale_new ((GtkAdjustment *) gtk_adjustment_new (80, 0, 100, 1, 5, 0));
     g_object_set_data (G_OBJECT (notebook), "vol_scale", vol_scale);
     gtk_scale_set_value_pos (GTK_SCALE (vol_scale), GTK_POS_RIGHT);
     gtk_scale_set_digits (GTK_SCALE (vol_scale), 0);
     label = gtk_label_new ("%");
-    hbox2 = gtk_hbox_new (FALSE, 6);
-    gtk_box_pack_start (GTK_BOX (hbox2), vol_scale, TRUE, TRUE, 0);
-    gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
+    hbox2 = gtk_hbox_new (false, 6);
+    gtk_box_pack_start (GTK_BOX (hbox2), vol_scale, true, true, 0);
+    gtk_box_pack_start (GTK_BOX (hbox2), label, false, false, 0);
+    gtk_box_pack_start (GTK_BOX (vbox2), hbox2, false, false, 0);
 
     current_button = gtk_button_new_with_label (_("Current"));
     g_signal_connect (current_button, "clicked", G_CALLBACK (alarm_current_volume), nullptr);
-    gtk_box_pack_start (GTK_BOX (vbox2), current_button, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox2), current_button, false, false, 0);
 
     gtk_container_add (GTK_CONTAINER (frame), vbox2);
-    gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), frame, false, false, 0);
 
     label = gtk_label_new (_("Volume"));
     gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
 
 
     /* Page 4 */
-    vbox = gtk_vbox_new (FALSE, 6);
+    vbox = gtk_vbox_new (false, 6);
     frame = gtk_frame_new (_("Additional Command"));
-    hbox = gtk_hbox_new (FALSE, 6);
+    hbox = gtk_hbox_new (false, 6);
     gtk_container_set_border_width (GTK_CONTAINER (frame), 6);
     gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
     cmd_entry = gtk_entry_new ();
     g_object_set_data (G_OBJECT (notebook), "cmd_entry", cmd_entry);
     cmd_checkb = gtk_check_button_new_with_label (_("enable"));
     g_object_set_data (G_OBJECT (notebook), "cmd_checkb", cmd_checkb);
-    gtk_box_pack_start (GTK_BOX (hbox), cmd_entry, TRUE, TRUE, 0);
-    gtk_box_pack_start (GTK_BOX (hbox), cmd_checkb, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), cmd_entry, true, true, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), cmd_checkb, false, false, 0);
     gtk_container_add (GTK_CONTAINER (frame), hbox);
-    gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), frame, false, false, 0);
 
     frame = gtk_frame_new (_("Playlist (optional)"));
-    hbox = gtk_hbox_new (FALSE, 6);
+    hbox = gtk_hbox_new (false, 6);
     gtk_container_set_border_width (GTK_CONTAINER (frame), 6);
     gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
-    playlist_entry = gtk_entry_new ();
+    playlist_entry = audgui_file_entry_new (GTK_FILE_CHOOSER_ACTION_OPEN, _("Select a playlist"));
     g_object_set_data (G_OBJECT (notebook), "playlist", playlist_entry);
 
-    file_chooser_button = gtk_file_chooser_button_new (_("Select a playlist"), GTK_FILE_CHOOSER_ACTION_OPEN);
-    g_signal_connect (file_chooser_button, "file-set", G_CALLBACK (file_set_cb), playlist_entry);
-    gtk_box_pack_start (GTK_BOX (hbox), playlist_entry, TRUE, TRUE, 0);
-    gtk_box_pack_start (GTK_BOX (hbox), file_chooser_button, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), playlist_entry, true, true, 0);
     gtk_container_add (GTK_CONTAINER (frame), hbox);
-    gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), frame, false, false, 0);
 
     frame = gtk_frame_new (_("Reminder"));
-    hbox = gtk_hbox_new (FALSE, 6);
+    hbox = gtk_hbox_new (false, 6);
     gtk_container_set_border_width (GTK_CONTAINER (frame), 6);
     gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
     reminder_text = gtk_entry_new ();
     reminder_checkb = gtk_check_button_new_with_label (_("enable"));
     g_object_set_data (G_OBJECT (notebook), "reminder_text", reminder_text);
     g_object_set_data (G_OBJECT (notebook), "reminder_cb", reminder_checkb);
-    gtk_box_pack_start (GTK_BOX (hbox), reminder_text, TRUE, TRUE, 0);
-    gtk_box_pack_start (GTK_BOX (hbox), reminder_checkb, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), reminder_text, true, true, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), reminder_checkb, false, false, 0);
     gtk_container_add (GTK_CONTAINER (frame), hbox);
-    gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), frame, false, false, 0);
 
     label = gtk_label_new (_("Options"));
     gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
@@ -404,12 +390,10 @@ GtkWidget *create_config_notebook (void)
     frame = gtk_frame_new (_("What do these options mean?"));
     gtk_container_set_border_width (GTK_CONTAINER (frame), 6);
     view = gtk_text_view_new ();
-    gtk_text_view_set_editable (GTK_TEXT_VIEW (view), FALSE);
-    gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (view), FALSE);
+    gtk_text_view_set_editable (GTK_TEXT_VIEW (view), false);
+    gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (view), false);
     text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
-    help_text = g_strconcat (_(help[0]), _(help[1]), _(help[2]), nullptr);
-    gtk_text_buffer_set_text (text_buffer, help_text, -1);
-    g_free (help_text);
+    gtk_text_buffer_set_text (text_buffer, _(help_text), -1);
     scrolled_window = gtk_scrolled_window_new (nullptr, nullptr);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
      GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
