@@ -40,11 +40,11 @@ static void compute_sizes ()
     int dpi = audgui_get_dpi ();
 
     SPACING = aud::rescale (dpi, 12, 1);
-    ICON_SIZE = aud::rescale (dpi, 3, 2);
+    ICON_SIZE = 2 * aud::rescale (dpi, 3, 1); // should be divisible by 2
     HEIGHT = ICON_SIZE + 2 * SPACING;
     BAND_WIDTH = aud::rescale (dpi, 16, 1);
     BAND_SPACING = aud::rescale (dpi, 48, 1);
-    VIS_WIDTH = VIS_BANDS * (BAND_WIDTH + BAND_SPACING) - BAND_SPACING;
+    VIS_WIDTH = VIS_BANDS * (BAND_WIDTH + BAND_SPACING) - BAND_SPACING + 2 * SPACING;
     VIS_SCALE = aud::rescale (ICON_SIZE, 8, 5);
     VIS_CENTER = VIS_SCALE + SPACING;
 }
@@ -54,11 +54,10 @@ typedef struct {
 
     String title, artist, album;
     String last_title, last_artist, last_album;
+    AudguiPixbuf pb, last_pb;
     float alpha, last_alpha;
 
     bool stopped;
-
-    GdkPixbuf * pb, * last_pb;
 } UIInfoArea;
 
 class InfoAreaVis : public Visualizer
@@ -137,13 +136,26 @@ void InfoAreaVis::clear ()
 
 static void clear (GtkWidget * widget, cairo_t * cr)
 {
+    double r = 1, g = 1, b = 1;
+
+    /* In a dark theme, try to match the tone of the base color */
+    auto & c = (gtk_widget_get_style (widget))->base[GTK_STATE_NORMAL];
+    int v = aud::max (aud::max (c.red, c.green), c.blue);
+
+    if (v >= 10*256 && v < 80*256)
+    {
+        r = (double)c.red / v;
+        g = (double)c.green / v;
+        b = (double)c.blue / v;
+    }
+
     GtkAllocation alloc;
     gtk_widget_get_allocation (widget, & alloc);
 
     cairo_pattern_t * gradient = cairo_pattern_create_linear (0, 0, 0, alloc.height);
-    cairo_pattern_add_color_stop_rgb (gradient, 0, 0.25, 0.25, 0.25);
-    cairo_pattern_add_color_stop_rgb (gradient, 0.5, 0.15, 0.15, 0.15);
-    cairo_pattern_add_color_stop_rgb (gradient, 0.5, 0.1, 0.1, 0.1);
+    cairo_pattern_add_color_stop_rgb (gradient, 0, 0.25 * r, 0.25 * g, 0.25 * b);
+    cairo_pattern_add_color_stop_rgb (gradient, 0.5, 0.15 * r, 0.15 * g, 0.15 * b);
+    cairo_pattern_add_color_stop_rgb (gradient, 0.5, 0.1 * r, 0.1 * g, 0.1 * b);
     cairo_pattern_add_color_stop_rgb (gradient, 1, 0, 0, 0);
 
     cairo_set_source (cr, gradient);
@@ -242,10 +254,10 @@ static void hsv_to_rgb (float h, float s, float v, float * r, float * g,
 
 static void get_color (GtkWidget * widget, int i, float * r, float * g, float * b)
 {
-    GdkColor * c = (gtk_widget_get_style (widget))->base + GTK_STATE_SELECTED;
+    auto & c = (gtk_widget_get_style (widget))->base[GTK_STATE_SELECTED];
     float h, s, v;
 
-    rgb_to_hsv (c->red / 65535.0, c->green / 65535.0, c->blue / 65535.0, & h, & s, & v);
+    rgb_to_hsv (c.red / 65535.0, c.green / 65535.0, c.blue / 65535.0, & h, & s, & v);
 
     if (s < 0.1) /* monochrome theme? use blue instead */
         h = 4.6;
@@ -290,17 +302,17 @@ static void draw_album_art (cairo_t * cr)
 
     if (area->pb)
     {
-        int left = SPACING + (ICON_SIZE - gdk_pixbuf_get_width (area->pb)) / 2;
-        int top = SPACING + (ICON_SIZE - gdk_pixbuf_get_height (area->pb)) / 2;
-        gdk_cairo_set_source_pixbuf (cr, area->pb, left, top);
+        int left = SPACING + (ICON_SIZE - area->pb.width ()) / 2;
+        int top = SPACING + (ICON_SIZE - area->pb.height ()) / 2;
+        gdk_cairo_set_source_pixbuf (cr, area->pb.get (), left, top);
         cairo_paint_with_alpha (cr, area->alpha);
     }
 
     if (area->last_pb)
     {
-        int left = SPACING + (ICON_SIZE - gdk_pixbuf_get_width (area->last_pb)) / 2;
-        int top = SPACING + (ICON_SIZE - gdk_pixbuf_get_height (area->last_pb)) / 2;
-        gdk_cairo_set_source_pixbuf (cr, area->last_pb, left, top);
+        int left = SPACING + (ICON_SIZE - area->last_pb.width ()) / 2;
+        int top = SPACING + (ICON_SIZE - area->last_pb.height ()) / 2;
+        gdk_cairo_set_source_pixbuf (cr, area->last_pb.get (), left, top);
         cairo_paint_with_alpha (cr, area->last_alpha);
     }
 }
@@ -395,28 +407,22 @@ static void set_album_art ()
 {
     g_return_if_fail (area);
 
-    if (area->pb)
-        g_object_unref (area->pb);
-
     area->pb = audgui_pixbuf_request_current ();
-    if (! area->pb)
-        area->pb = audgui_pixbuf_fallback ();
+
     if (area->pb)
-        audgui_pixbuf_scale_within (& area->pb, ICON_SIZE);
+        audgui_pixbuf_scale_within (area->pb, ICON_SIZE);
+    else
+        area->pb = audgui_pixbuf_fallback ();
 }
 
 static void infoarea_next ()
 {
     g_return_if_fail (area);
 
-    if (area->last_pb)
-        g_object_unref (area->last_pb);
-    area->last_pb = area->pb;
-    area->pb = nullptr;
-
     area->last_title = std::move (area->title);
     area->last_artist = std::move (area->artist);
     area->last_album = std::move (area->album);
+    area->last_pb = std::move (area->pb);
 
     area->last_alpha = area->alpha;
     area->alpha = 0;
@@ -469,7 +475,7 @@ void ui_infoarea_show_vis (bool show)
         /* note: "realize" signal must be connected before adding to box */
         g_signal_connect (vis.widget, "realize", (GCallback) realize_cb, nullptr);
 
-        gtk_widget_set_size_request (vis.widget, VIS_WIDTH + 2 * SPACING, HEIGHT);
+        gtk_widget_set_size_request (vis.widget, VIS_WIDTH, HEIGHT);
         gtk_box_pack_start ((GtkBox *) area->box, vis.widget, false, false, 0);
 
         g_signal_connect (vis.widget, "expose-event", (GCallback) expose_vis_cb, nullptr);
@@ -503,11 +509,6 @@ static void destroy_cb (GtkWidget * widget)
 
     timer_remove (TimerRate::Hz30, ui_infoarea_do_fade);
 
-    if (area->pb)
-        g_object_unref (area->pb);
-    if (area->last_pb)
-        g_object_unref (area->last_pb);
-
     delete area;
     area = nullptr;
 }
