@@ -30,6 +30,7 @@
 #include <libaudcore/audstrings.h>
 #include <libaudcore/preferences.h>
 #include <libaudcore/runtime.h>
+#include <libaudgui/libaudgui-gtk.h>
 
 #include "plugin.h"
 
@@ -109,7 +110,7 @@ static void open_plugin (const char * path, const LADSPA_Descriptor & desc)
     g_return_if_fail (slash && slash[1]);
     g_return_if_fail (desc.Label && desc.Name);
 
-    PluginData & plugin = * plugins.append (SmartNew<PluginData> (slash + 1, desc));
+    PluginData & plugin = * plugins.append (new PluginData (slash + 1, desc));
 
     for (unsigned i = 0; i < desc.PortCount; i ++)
     {
@@ -203,7 +204,7 @@ static void close_modules ()
 
 LoadedPlugin & enable_plugin_locked (PluginData & plugin)
 {
-    LoadedPlugin & loaded = * loadeds.append (SmartNew<LoadedPlugin> (plugin));
+    LoadedPlugin & loaded = * loadeds.append (new LoadedPlugin (plugin));
 
     for (auto & control : plugin.controls)
         loaded.values.append (control.def);
@@ -423,7 +424,7 @@ static void configure_plugin (LoadedPlugin & loaded)
     {
         ControlData & control = plugin.controls[i];
 
-        GtkWidget * hbox = gtk_hbox_new (FALSE, 6);
+        GtkWidget * hbox = gtk_hbox_new (false, 6);
         gtk_box_pack_start ((GtkBox *) vbox, hbox, 0, 0, 0);
 
         if (control.is_toggle)
@@ -469,10 +470,12 @@ static void configure_selected ()
 
 static void * make_config_widget ()
 {
-    GtkWidget * vbox = gtk_vbox_new (FALSE, 6);
-    gtk_widget_set_size_request (vbox, 480, 360);
+    int dpi = audgui_get_dpi ();
 
-    GtkWidget * hbox = gtk_hbox_new (FALSE, 6);
+    GtkWidget * vbox = gtk_vbox_new (false, 6);
+    gtk_widget_set_size_request (vbox, 5 * dpi, 4 * dpi);
+
+    GtkWidget * hbox = gtk_hbox_new (false, 6);
     gtk_box_pack_start ((GtkBox *) vbox, hbox, 0, 0, 0);
 
     GtkWidget * label = gtk_label_new (_("Module paths:"));
@@ -490,10 +493,10 @@ static void * make_config_widget ()
     GtkWidget * entry = gtk_entry_new ();
     gtk_box_pack_start ((GtkBox *) hbox, entry, 1, 1, 0);
 
-    hbox = gtk_hbox_new (FALSE, 6);
+    hbox = gtk_hbox_new (false, 6);
     gtk_box_pack_start ((GtkBox *) vbox, hbox, 1, 1, 0);
 
-    GtkWidget * vbox2 = gtk_vbox_new (FALSE, 6);
+    GtkWidget * vbox2 = gtk_vbox_new (false, 6);
     gtk_box_pack_start ((GtkBox *) hbox, vbox2, 1, 1, 0);
 
     label = gtk_label_new (_("Available plugins:"));
@@ -506,13 +509,13 @@ static void * make_config_widget ()
     plugin_list = create_plugin_list ();
     gtk_container_add ((GtkContainer *) scrolled, plugin_list);
 
-    GtkWidget * hbox2 = gtk_hbox_new (FALSE, 6);
+    GtkWidget * hbox2 = gtk_hbox_new (false, 6);
     gtk_box_pack_start ((GtkBox *) vbox2, hbox2, 0, 0, 0);
 
     GtkWidget * enable_button = gtk_button_new_with_label (_("Enable"));
     gtk_box_pack_end ((GtkBox *) hbox2, enable_button, 0, 0, 0);
 
-    vbox2 = gtk_vbox_new (FALSE, 6);
+    vbox2 = gtk_vbox_new (false, 6);
     gtk_box_pack_start ((GtkBox *) hbox, vbox2, 1, 1, 0);
 
     label = gtk_label_new (_("Enabled plugins:"));
@@ -525,7 +528,7 @@ static void * make_config_widget ()
     loaded_list = create_loaded_list ();
     gtk_container_add ((GtkContainer *) scrolled, loaded_list);
 
-    hbox2 = gtk_hbox_new (FALSE, 6);
+    hbox2 = gtk_hbox_new (false, 6);
     gtk_box_pack_start ((GtkBox *) vbox2, hbox2, 0, 0, 0);
 
     GtkWidget * disable_button = gtk_button_new_with_label (_("Disable"));
