@@ -24,9 +24,9 @@
 #include <QWidget>
 
 #include <libaudcore/hook.h>
-#include <libaudcore/visualizer.h>
 
 class InfoVis;
+struct PixelSizes;
 
 class InfoBar : public QWidget
 {
@@ -37,18 +37,38 @@ public:
     void paintEvent (QPaintEvent *);
 
 private:
-    void update_metadata_cb ();
-    void update_cb ();
+    void update_title ();
+    void update_album_art ();
+    void next_song ();
+    void do_fade ();
+
+    void playback_ready_cb ();
+    void playback_stop_cb ();
+    void update_vis ();
 
     const HookReceiver<InfoBar>
-     hook1 {"tuple change", this, & InfoBar::update_metadata_cb},
-     hook2 {"playback ready", this, & InfoBar::update_cb},
-     hook3 {"playback stop", this, & InfoBar::update_cb};
+     hook1 {"tuple change", this, & InfoBar::update_title},
+     hook2 {"playback ready", this, & InfoBar::playback_ready_cb},
+     hook3 {"playback stop", this, & InfoBar::playback_stop_cb},
+     hook4 {"qtui toggle infoarea_vis", this, & InfoBar::update_vis};
+
+    const Timer<InfoBar>
+     fade_timer {TimerRate::Hz30, this, & InfoBar::do_fade};
 
-    QPixmap m_art;
-    QString m_original_title;
-    QStaticText m_title, m_artist, m_album;
     InfoVis * m_vis;
+    const PixelSizes & ps;
+
+    struct SongData {
+        QPixmap art;
+        QString orig_title;
+        QStaticText title, artist, album;
+        int alpha;
+    };
+
+    enum {Prev = 0, Cur = 1}; /* index into SongData array */
+
+    SongData sd[2];
+    bool m_stopped;
 };
 
 #endif
