@@ -11,7 +11,6 @@ bool xs_sidplayfp_init();
 bool xs_sidplayfp_initsong(int subtune);
 unsigned xs_sidplayfp_fillbuffer(char *, unsigned);
 bool xs_sidplayfp_load(const void *buf, int64_t bufSize);
-bool xs_sidplayfp_getinfo(xs_tuneinfo_t &ti, const char *filename, const void *buf, int64_t bufSize);
-bool xs_sidplayfp_updateinfo(xs_tuneinfo_t &ti, int subtune);
+bool xs_sidplayfp_getinfo(xs_tuneinfo_t &ti, const void *buf, int64_t bufSize);
 
 #endif /* XS_SIDPLAYFP_H */
