@@ -19,9 +19,7 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include <math.h>
 #include <stdlib.h>
-
 #include <sndfile.h>
 
 #define WANT_VFS_STDIO_COMPAT
@@ -41,14 +39,12 @@ public:
         about
     };
 
-    static constexpr auto iinfo = InputInfo ()
+    constexpr SndfilePlugin () : InputPlugin (info, InputInfo ()
         .with_priority (9)  /* low priority fallback (but before ffaudio) */
-        .with_exts (exts);
-
-    constexpr SndfilePlugin () : InputPlugin (info, iinfo) {}
+        .with_exts (exts)) {}
 
     bool is_our_file (const char * filename, VFSFile & file);
-    Tuple read_tuple (const char * filename, VFSFile & file);
+    bool read_tag (const char * filename, VFSFile & file, Tuple & tuple, Index<char> * image);
     bool play (const char * filename, VFSFile & file);
 };
 
@@ -59,13 +55,23 @@ EXPORT SndfilePlugin aud_plugin_instance;
 static sf_count_t
 sf_get_filelen (void *user_data)
 {
-    return ((VFSFile *) user_data)->fsize ();
+    int64_t size = ((VFSFile *) user_data)->fsize ();
+    return (size < 0) ? SF_COUNT_MAX : size;
 }
 
 static sf_count_t
 sf_vseek (sf_count_t offset, int whence, void *user_data)
 {
-    return ((VFSFile *) user_data)->fseek (offset, to_vfs_seek_type (whence));
+    if (((VFSFile *) user_data)->fseek (offset, to_vfs_seek_type (whence)) != 0)
+        return -1;
+
+    return ((VFSFile *) user_data)->ftell ();
+}
+
+static sf_count_t
+sf_vseek_dummy (sf_count_t offset, int whence, void *user_data)
+{
+    return -1;
 }
 
 static sf_count_t
@@ -75,9 +81,9 @@ sf_vread (void *ptr, sf_count_t count, void *user_data)
 }
 
 static sf_count_t
-sf_vwrite (const void *ptr, sf_count_t count, void *user_data)
+sf_vwrite_dummy (const void *ptr, sf_count_t count, void *user_data)
 {
-    return ((VFSFile *) user_data)->fwrite (ptr, 1, count);
+    return 0;
 }
 
 static sf_count_t
@@ -91,7 +97,16 @@ static SF_VIRTUAL_IO sf_virtual_io =
     sf_get_filelen,
     sf_vseek,
     sf_vread,
-    sf_vwrite,
+    sf_vwrite_dummy,
+    sf_tell
+};
+
+static SF_VIRTUAL_IO sf_virtual_io_stream =
+{
+    sf_get_filelen,
+    sf_vseek_dummy,
+    sf_vread,
+    sf_vwrite_dummy,
     sf_tell
 };
 
@@ -109,32 +124,34 @@ static void copy_int (SNDFILE * sf, int sf_id, Tuple & tup, Tuple::Field field)
         tup.set_int (field, atoi (str));
 }
 
-Tuple SndfilePlugin::read_tuple (const char * filename, VFSFile & file)
+bool SndfilePlugin::read_tag (const char * filename, VFSFile & file, Tuple & tuple,
+ Index<char> * image)
 {
-    SNDFILE *sndfile;
     SF_INFO sfinfo {}; // must be zeroed before sf_open()
     const char *format, *subformat;
-    Tuple ti;
 
-    sndfile = sf_open_virtual (& sf_virtual_io, SFM_READ, & sfinfo, & file);
+    bool stream = (file.fsize () < 0);
+    SNDFILE * sndfile = sf_open_virtual (stream ? & sf_virtual_io_stream :
+     & sf_virtual_io, SFM_READ, & sfinfo, & file);
 
-    if (sndfile == nullptr)
-        return ti;
+    if (! sndfile)
+        return false;
 
-    ti.set_filename (filename);
-
-    copy_string (sndfile, SF_STR_TITLE, ti, Tuple::Title);
-    copy_string (sndfile, SF_STR_ARTIST, ti, Tuple::Artist);
-    copy_string (sndfile, SF_STR_ALBUM, ti, Tuple::Album);
-    copy_string (sndfile, SF_STR_COMMENT, ti, Tuple::Comment);
-    copy_string (sndfile, SF_STR_GENRE, ti, Tuple::Genre);
-    copy_int (sndfile, SF_STR_DATE, ti, Tuple::Year);
-    copy_int (sndfile, SF_STR_TRACKNUMBER, ti, Tuple::Track);
+    copy_string (sndfile, SF_STR_TITLE, tuple, Tuple::Title);
+    copy_string (sndfile, SF_STR_ARTIST, tuple, Tuple::Artist);
+    copy_string (sndfile, SF_STR_ALBUM, tuple, Tuple::Album);
+    copy_string (sndfile, SF_STR_COMMENT, tuple, Tuple::Comment);
+    copy_string (sndfile, SF_STR_GENRE, tuple, Tuple::Genre);
+    copy_int (sndfile, SF_STR_DATE, tuple, Tuple::Year);
+    copy_int (sndfile, SF_STR_TRACKNUMBER, tuple, Tuple::Track);
 
     sf_close (sndfile);
 
     if (sfinfo.samplerate > 0)
-        ti.set_int (Tuple::Length, ceil (1000.0 * sfinfo.frames / sfinfo.samplerate));
+    {
+        int64_t length = aud::rescale<int64_t> (sfinfo.frames, sfinfo.samplerate, 1000);
+        tuple.set_int (Tuple::Length, length);
+    }
 
     switch (sfinfo.format & SF_FORMAT_TYPEMASK)
     {
@@ -276,18 +293,22 @@ Tuple SndfilePlugin::read_tuple (const char * filename, VFSFile & file)
     }
 
     if (subformat != nullptr)
-        ti.set_format (str_printf ("%s (%s)", format, subformat),
+        tuple.set_format (str_printf ("%s (%s)", format, subformat),
          sfinfo.channels, sfinfo.samplerate, 0);
     else
-        ti.set_format (format, sfinfo.channels, sfinfo.samplerate, 0);
+        tuple.set_format (format, sfinfo.channels, sfinfo.samplerate, 0);
 
-    return ti;
+    return true;
 }
 
 bool SndfilePlugin::play (const char * filename, VFSFile & file)
 {
     SF_INFO sfinfo {}; // must be zeroed before sf_open()
-    SNDFILE * sndfile = sf_open_virtual (& sf_virtual_io, SFM_READ, & sfinfo, & file);
+
+    bool stream = (file.fsize () < 0);
+    SNDFILE * sndfile = sf_open_virtual (stream ? & sf_virtual_io_stream :
+     & sf_virtual_io, SFM_READ, & sfinfo, & file);
+
     if (sndfile == nullptr)
         return false;
 
@@ -300,7 +321,10 @@ bool SndfilePlugin::play (const char * filename, VFSFile & file)
     {
         int seek_value = check_seek ();
         if (seek_value != -1)
-            sf_seek (sndfile, (int64_t) seek_value * sfinfo.samplerate / 1000, SEEK_SET);
+        {
+            int64_t frames = aud::rescale<int64_t> (seek_value, 1000, sfinfo.samplerate);
+            sf_seek (sndfile, aud::min (frames, (int64_t) sfinfo.frames), SEEK_SET);
+        }
 
         int samples = sf_read_float (sndfile, buffer.begin (), buffer.len ());
         if (! samples)
@@ -316,11 +340,12 @@ bool SndfilePlugin::play (const char * filename, VFSFile & file)
 
 bool SndfilePlugin::is_our_file (const char * filename, VFSFile & file)
 {
-    SNDFILE *tmp_sndfile;
     SF_INFO tmp_sfinfo {}; // must be zeroed before sf_open()
 
     /* Have to open the file to see if libsndfile can handle it. */
-    tmp_sndfile = sf_open_virtual (&sf_virtual_io, SFM_READ, &tmp_sfinfo, &file);
+    bool stream = (file.fsize () < 0);
+    SNDFILE * tmp_sndfile = sf_open_virtual (stream ? & sf_virtual_io_stream :
+     & sf_virtual_io, SFM_READ, & tmp_sfinfo, & file);
 
     if (!tmp_sndfile)
         return false;
