@@ -20,7 +20,6 @@
 #include <libaudcore/i18n.h>
 #include <libaudcore/drct.h>
 #include <libaudcore/hook.h>
-#include <libaudcore/mainloop.h>
 #include <libaudcore/plugin.h>
 #include <libaudcore/runtime.h>
 #include <libaudcore/interface.h>
@@ -121,11 +120,6 @@ class SystemTrayIcon : public QSystemTrayIcon
 public:
     SystemTrayIcon (const QIcon & icon, QObject * parent = nullptr) :
         QSystemTrayIcon (icon, parent) {}
-    ~SystemTrayIcon ()
-        { hide_popup (); }
-
-    void show_popup ();
-    void hide_popup ();
 
 protected:
     void scroll (int steps);
@@ -133,8 +127,6 @@ protected:
 
 private:
     int scroll_delta = 0;
-    bool popup_shown = false;
-    QueuedFunc popup_timer;
 };
 
 void SystemTrayIcon::scroll (int delta)
@@ -170,7 +162,7 @@ bool SystemTrayIcon::event (QEvent * e)
     {
     case QEvent::ToolTip:
         if (! aud_get_bool ("statusicon", "disable_popup"))
-            show_popup ();
+            audqt::infopopup_show_current ();
         return true;
 
     case QEvent::Wheel:
@@ -182,22 +174,6 @@ bool SystemTrayIcon::event (QEvent * e)
     }
 }
 
-void SystemTrayIcon::show_popup ()
-{
-    audqt::infopopup_show_current ();
-    popup_timer.queue (5000, aud::obj_member<SystemTrayIcon, & SystemTrayIcon::hide_popup>, this);
-    popup_shown = true;
-}
-
-void SystemTrayIcon::hide_popup ()
-{
-    if (popup_shown)
-    {
-        audqt::infopopup_hide ();
-        popup_shown = false;
-    }
-}
-
 static SystemTrayIcon * tray = nullptr;
 static QMenu * menu = nullptr;
 
@@ -210,7 +186,6 @@ bool StatusIcon::init ()
     tray = new SystemTrayIcon (qApp->windowIcon ());
     QObject::connect (tray, & QSystemTrayIcon::activated, activate);
     menu = audqt::menu_build (items);
-    QObject::connect (menu, & QMenu::aboutToShow, tray, & SystemTrayIcon::hide_popup);
     tray->setContextMenu (menu);
     tray->show ();
 
