@@ -20,16 +20,13 @@ public:
         about
     };
 
-    static constexpr auto iinfo = InputInfo (FlagWritesTag)
+    constexpr VorbisPlugin () : InputPlugin (info, InputInfo (FlagWritesTag)
         .with_priority (2)  /* medium-high priority (a little slow) */
         .with_exts (exts)
-        .with_mimes (mimes);
-
-    constexpr VorbisPlugin () : InputPlugin (info, iinfo) {}
+        .with_mimes (mimes)) {}
 
     bool is_our_file (const char * filename, VFSFile & file);
-    Tuple read_tuple (const char * filename, VFSFile & file);
-    Index<char> read_image (const char * filename, VFSFile & file);
+    bool read_tag (const char * filename, VFSFile & file, Tuple & tuple, Index<char> * image);
     bool write_tuple (const char * filename, VFSFile & file, const Tuple & tuple);
     bool play (const char * filename, VFSFile & file);
 };
